==> dde-dock_5.4.7.orig.tar.xz: dde-dock-5.4.7/translations/dde-dock_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>De invoegtoepassing &apos;%1&apos; is niet compatibel met het systeem.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-instellingen</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-instellingen</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbonden</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bezig met verbinden...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Toetsenbordindeling toevoegen</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-uursklok</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-uursklok</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tijdinstellingen</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Weet je zeker dat je 1% objecten wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Deze actie kan niet ongedaan worden gemaakt</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Onbekend apparaat</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Onbekende schijf</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Schijf</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Alles ontkoppelen</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Programmastarter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>Invoegtoepassingen</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Venster- en werkbladoverzicht</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Bekabelde verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Bekabelde verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Draadloze verbinding uitschakelen</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Draadloze verbinding inschakelen</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Netwerk uitschakelen</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Netwerk inschakelen</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netwerkinstellingen</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>Apparaat uitgeschakeld</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>Draadloze verbinding: %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>Bekabelde verbinding: %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Niet verbonden</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Bezig met verbinden</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Verbonden, maar geen internettoegang</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netwerkkabel is niet aangesloten</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Verbinding mislukt</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Bekabeld netwerk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Bekabeld netwerk: %1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capaciteit: %1 - %2 min resterend</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capaciteit: %1 - %2 uur en %3 min resterend</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 opgeladen - klaar over %2 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 opgeladen - klaar over %2 uur en %3 min</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>Opgeladen</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capaciteit: %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Bezig met opladen %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capaciteit: %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capaciteit: %1 - volledig opgeladen</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Bureaublad tonen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Ander account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>Apparaat</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ontdempen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Geluidsinstellingen</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>%1 volume</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Prullenbak - %1 bestand</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Prullenbak - %1 bestanden</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Leeg</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>Systeemvak</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>Draadloos netwerk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Draadloos netwerk: %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>‘%1’ is niet compatibel met het systeem.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>De vliegtuigstand is ingeschakeld</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>Vliegtuigstandinstellingen</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>De vliegtuigstand is uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Vliegtuigstand</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-instellingen</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth-instellingen</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 verbonden</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Bezig met verbinden…</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Uitgeschakeld</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Toetsenbordindeling toevoegen</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Datum en tijd</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12-uursklok</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24-uursklok</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Tijdinstellingen</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Maandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dinsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Woensdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donderdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Vrijdag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Zaterdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Zondag</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>maandag</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>dinsdag</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>woensdag</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>donderdag</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>vrijdag</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>zaterdag</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>zondag</translation>
    </message>
    <message>
        <source>%1year%2month%3day</source>
        <translation>%1jaar%2maand%3dag</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>Weet je zeker dat je 1% objecten wilt verwijderen?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>Deze actie kan niet ongedaan worden gemaakt</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>Onbekend apparaat</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>Onbekende schijf</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>Schijf</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>Alles ontkoppelen</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>Programmastarter</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>Veilige modus afsluiten</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>Dock - Veilige modus</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>Het dock draait in de veilige modus. Sluit af om het dock correct te tonen.</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>Dockinstellingen</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>Meerdere beeldschermen</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Invoegtoepassingsgebied</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>Geef aan welke pictogrammen moeten worden getoond op het dock</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
        <extra-child_page>Dock</extra-child_page>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
    <message>
        <source>Small</source>
        <translation>Klein</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groot</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dock tonen</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>Op het scherm waar de cursor is</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>Alleen op hoofdscherm</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>Venster- en werkbladoverzicht</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Capaciteit: %1 - %2 min resterend</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Capaciteit: %1 - %2 uur en %3 min resterend</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>%1 opgeladen - klaar over %2 min</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>%1 opgeladen - klaar over %2 uur en %3 min</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Capaciteit: %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Bezig met opladen %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Capaciteit: %1 …</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Capaciteit: %1 - volledig opgeladen</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>Vastmaken</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Grootte</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>Dock tonen</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>Invoegtoepassingsgebied</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>Bureaublad tonen</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Losmaken</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>Energie</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>Ander account</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energie-instellingen</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>Ontdempen</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Dempen</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Geluidsinstellingen</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>%1 volume</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Geen uitvoerapparaten</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Geluid</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>Prullenbak</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>Prullenbak - %1 bestand</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>Prullenbak - %1 bestanden</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>Verplaatsen naar prullenbak</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>Openen</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>Leeg</translation>
    </message>
</context>
</TS>
